@@ -69,13 +69,6 @@ class JacobianTracer(myokit.CppModule):
         }
         fname = os.path.join(myokit.DIR_CFUNC, SOURCE_FILE)
 
-        # Debug
-        if myokit.DEBUG:
-            print(self._code(fname, args,
-                             line_numbers=myokit.DEBUG_LINE_NUMBERS))
-            import sys
-            sys.exit(1)
-
         # Define libraries
         libs = []
         if platform.system() != 'Windows':  # pragma: no windows cover
@@ -248,14 +241,6 @@ class JacobianCalculator(myokit.CppModule):
         }
         fname = os.path.join(myokit.DIR_CFUNC, SOURCE_FILE)
 
-        # Debug
-        if myokit.DEBUG:
-            print(
-                self._code(fname, args, line_numbers=myokit.DEBUG_LINE_NUMBERS)
-            )
-            import sys
-            sys.exit(1)
-
         # Define libraries
         libs = []
         if platform.system() != 'Windows':  # pragma: no windows cover
