@@ -3,10 +3,8 @@
 # model_wrapper.m :: Creates a wrapper around the model function so that it can
 # be used in matlab/octave style ode solvers.
 #
-# This file is part of Myokit
-#  Copyright 2011-2018 Maastricht University, University of Oxford
-#  Licensed under the GNU General Public License v3.0
-#  See: http://myokit.org
+# This file is part of Myokit.
+# See http://myokit.org for copyright, sharing, and licensing details.
 #
 ?>% Function wrapper
 function ydot = model_wrapper(t, y, c)
