@@ -19,7 +19,7 @@ import numpy as np
 
 import myokit
 
-from shared import DIR_DATA, CancellingReporter, WarningCollector
+from myokit.tests import DIR_DATA, CancellingReporter, WarningCollector
 
 # Unit testing in Python 2 and 3
 try:
